@@ -1,5 +1,7 @@
 from snatch.banco_central import BancoCentral  # noqa
 from snatch.boa_vista import BoaVista  # noqa
+from snatch.cgu_pep import PEP  # noqa
 from snatch.qsa import QSA  # noqa
+from snatch.receita_federal_pj import ReceitaFederalPJ  # noqa
 
-__version__ = "2.4.0"
+__version__ = "2.7.1"
