@@ -19,7 +19,18 @@ def get_environment_from_secrets_manager(
 
     :return Dict[Any, Any]
     """
-    current_env = os.getenv("ENV", "production") if not environment else environment
+    env_name = os.getenv("ENV", "prd") if not environment else environment
+
+    env_names = {
+        "production": "prd",
+        "staging": "stg",
+        "develop": "dev",
+        "local": "local",
+        "dev": "dev",
+        "stg": "stg",
+        "prd": "prd",
+    }
+    current_env = env_names[env_name.strip().lower()]
 
     if "local" not in current_env:
         logger.remove()
@@ -33,6 +44,7 @@ def get_environment_from_secrets_manager(
 
     secrets_manager_data = {"current_environment": current_env}
     if not secrets.can_read_secrets:
+        logger.warning("Not reading Secrets Manager. Using local configuration...")
         return secrets_manager_data
 
     logger.info(
@@ -62,6 +74,14 @@ def get_settings(environment: Optional[str], log_level: str):
             "datasource_qsa_url": os.getenv(
                 "SNATCH_DATASOURCE_QSA_URL", "http://datasource_qsa"
             ),
+            "pep_secret_token": os.getenv("SNATCH_PEP_SECRET_TOKEN", "foo"),
+            "datasource_pep_url": os.getenv(
+                "SNATCH_DATASOURCE_PEP_URL", "http://datasource_pep"
+            ),
+            "rf_secret_token": os.getenv("SNATCH_RF_SECRET_TOKEN", "foo"),
+            "datasource_rf_url": os.getenv(
+                "SNATCH_DATASOURCE_RF_URL", "http://datasource_pep"
+            ),
         }
     }
     config.update(
